Trait RIType Copy item path Source pub trait RIType {
type FFIType : IntoValue + TryFromValue ;
}Expand description Something that can be used by the runtime interface as type to communicate between wasm and the
host.
Every type that should be used in a runtime interface function signature needs to implement
this trait.
The ffi type that is used to represent Self.
This trait is dyn compatible .
In older versions of Rust, dyn compatibility was called "object safety".
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
The u32 is the pointer to the array.
Source  The type is passed directly.
Source  The type is passed directly.
Source  The type is passed directly.
Source  The type is passed directly.
The u32 is a pointer to an [u8; 16] array.
The u64 value is build by length 32bit << 32 | pointer 32bit
The length and the pointer are taken directly from Self.
Source  The type is passed directly.
Source  The type is passed directly.
Source  The type is passed directly.
Source  The type is passed directly.
The u32 is a pointer to an [u8; 16] array.
The u64 value is build by length 32bit << 32 | pointer 32bit
If T == u8 the length and the pointer are taken directly from Self.
Otherwise Self is encoded and the length and the pointer are taken from the encoded vector.
The u64 value is build by length 32bit << 32 | pointer 32bit
If T == u8 the length and the pointer are taken directly from Self.
Otherwise Self is encoded and the length and the pointer are taken from the encoded vector.
The u64 value is build by length 32bit << 32 | pointer 32bit
Self is encoded and the length and the pointer are taken from the encoded vector.
The value is corresponds to the discriminant of the variant.
Source  The type is passed as the inner type.
Source  Available on crate feature std only.